@@ -1,5 +1,4 @@
-from .main import run
-
+from .main import run  # noqa: F401
 from .utils.logger import configure_logging
 
 configure_logging()
